--- modules/misc/logger.c.org	2008-03-11 15:05:24.000000000 +0100
+++ modules/misc/logger.c	2008-03-11 15:20:43.000000000 +0100
@@ -83,6 +83,7 @@
 
     FILE *    p_file; /* The log file */
     msg_subscription_t *p_sub;
+	int i_verbose;
 };
 
 /*****************************************************************************
@@ -92,7 +93,7 @@
 static void Close   ( vlc_object_t * );
 static void Run     ( intf_thread_t * );
 
-static void FlushQueue        ( msg_subscription_t *, FILE *, int );
+static void FlushQueue        ( msg_subscription_t *, FILE *, int, int );
 static void TextPrint         ( const msg_item_t *, FILE * );
 static void HtmlPrint         ( const msg_item_t *, FILE * );
 #ifdef HAVE_SYSLOG_H
@@ -271,10 +272,12 @@
     {
         p_intf->p_sys->p_file = NULL;
 #ifdef HAVE_SYSLOG_H
-        openlog( "VLC", 0, LOG_DAEMON );
+        openlog( "vlc", LOG_PID|LOG_NDELAY, LOG_DAEMON );
 #endif
     }
 
+	p_intf->p_sys->i_verbose = p_intf->p_libvlc->i_verbose;
+
     p_intf->p_sys->last_update = 0;
     p_intf->p_sys->p_rrd = NULL;
 
@@ -299,7 +302,7 @@
 
     /* Flush the queue and unsubscribe from the message queue */
     FlushQueue( p_intf->p_sys->p_sub, p_intf->p_sys->p_file,
-                p_intf->p_sys->i_mode );
+                p_intf->p_sys->i_mode, p_intf->p_sys->i_verbose );
     msg_Unsubscribe( p_intf, p_intf->p_sys->p_sub );
 
     switch( p_intf->p_sys->i_mode )
@@ -337,7 +340,7 @@
     while( !p_intf->b_die )
     {
         FlushQueue( p_intf->p_sys->p_sub, p_intf->p_sys->p_file,
-                    p_intf->p_sys->i_mode );
+                    p_intf->p_sys->i_mode, p_intf->p_sys->i_verbose );
 
         if( p_intf->p_sys->p_rrd )
             DoRRD( p_intf );
@@ -349,7 +352,7 @@
 /*****************************************************************************
  * FlushQueue: flush the message queue into the log
  *****************************************************************************/
-static void FlushQueue( msg_subscription_t *p_sub, FILE *p_file, int i_mode )
+static void FlushQueue( msg_subscription_t *p_sub, FILE *p_file, int i_mode, int i_verbose )
 {
     int i_start, i_stop;
 
@@ -364,6 +367,22 @@
              i_start != i_stop;
              i_start = (i_start+1) % VLC_MSG_QSIZE )
         {
+			switch( p_sub->p_msg[i_start].i_type )
+			{
+			case VLC_MSG_ERR:
+				if( i_verbose < 0 ) continue;
+				break;
+			case VLC_MSG_INFO:
+				if( i_verbose < 0 ) continue;
+				break;
+			case VLC_MSG_WARN:
+				if( i_verbose < 1 ) continue;
+				break;
+			case VLC_MSG_DBG:
+				if( i_verbose < 2 ) continue;
+				break;
+			}
+
             switch( i_mode )
             {
             case MODE_HTML:
@@ -402,6 +421,10 @@
 static void SyslogPrint( const msg_item_t *p_msg )
 {
     int i_priority = LOG_INFO;
+	static const char *c_priority[4] = { "_INFO_",
+										 "_ERR_",
+										 "_WARNING_",
+										 "_DEBUG_" };
 
     if( p_msg->i_type  == 0 ) i_priority = LOG_INFO;
     if( p_msg->i_type  == 1 ) i_priority = LOG_ERR;
@@ -409,10 +432,10 @@
     if( p_msg->i_type  == 3 ) i_priority = LOG_DEBUG;
 
     if( p_msg->psz_header )
-        syslog( i_priority, "%s %s: %s", p_msg->psz_header,
+        syslog( i_priority, "%s %s %s: %s", c_priority[p_msg->i_type], p_msg->psz_header,
                 p_msg->psz_module, p_msg->psz_msg );
     else
-        syslog( i_priority, "%s: %s", p_msg->psz_module, p_msg->psz_msg );
+        syslog( i_priority, "%s %s: %s", c_priority[p_msg->i_type], p_msg->psz_module, p_msg->psz_msg );
         
 }
 #endif
